API constants
*************

.. module:: spotify.constant

.. currentmodule:: spotify.constant

.. _user-relation-types:

User relation types
===================

.. data:: RELATION_TYPE_UNKNOWN

    Not yet known.

.. data:: RELATION_TYPE_NONE

    No relation.

.. data:: RELATION_TYPE_UNIDIRECTIONAL

    The currently logged in user is following this user.

.. data:: RELATION_TYPE_BIDIRECTIONAL

    Bidirectional friendship established.
